:sd_hide_title:
.. grid:: 1

    .. grid-item-card:: PyXMake as a CI/CD Catalog project

        Learn how to use `PyXMake`_ components

-----------------
Python components
-----------------

.. include:: ../../../README.md
	:start-line: 41
	:end-before: ## Contact
	:parser: myst_parser.docutils_

.. toctree::
   :hidden:
   :glob:

   ../pyx_catalog/python-create-wheel-w*
   ../pyx_catalog/python-create-wheel-m*
   ../pyx_catalog/python-create-wheel-o*
   ../pyx_catalog/python-create-wheel-a*
   ../pyx_catalog/python-publish-*
   ../pyx_catalog/python-audit-*
   ../pyx_catalog/python-run-*

.. _PyXMake: https://pypi.org/project/pyxmake